@@ -787,7 +787,7 @@ SPDX-License-Identifier: LGPL-3.0-or-later
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="683"/>
         <source>Custom toolbar</source>
-        <translation type="unfinished"/>
+        <translation>قورال ئىستونى بەلگىلەش</translation>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="691"/>
