@@ -626,7 +626,7 @@ void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 
     const QString &text = button->text();
 
-    if (text.count() == 2) {
+    if (text.size() == 2) {
         for (const QChar &ch : text) {
             switch (ch.script()) {
             case QChar::Script_Han:
@@ -1220,6 +1220,8 @@ void DDialog::changeEvent(QEvent *event)
             }
         }
         d->updateSize();
+    } else if (event->type() == QEvent::FontChange) {
+        d->updateSize();
     }
     return DAbstractDialog::changeEvent(event);
 }
