@@ -33,6 +33,17 @@
 DGUI_USE_NAMESPACE
 DWIDGET_BEGIN_NAMESPACE
 
+static QString truncateFileName(const QString &str, int maxLength = 255) {
+    if (str.length() <= maxLength)
+        return str;
+
+    int keepFront = (maxLength - 3) / 2; // 例如 maxLength=255 → keepFront=126
+    int keepBack = (maxLength - 3) - keepFront; // 126
+
+    // 截取前半部分 + "..." + 后半部分
+    return str.left(keepFront) + QString("...") + str.right(keepBack);
+}
+
 static void saveImageToFile(int index, const QString &outPutFileName, const QString &suffix, bool isJpegImage, const QImage &srcImage)
 {
     // write image
@@ -40,8 +51,12 @@ static void saveImageToFile(int index, const QString &outPutFileName, const QStr
     QString tmpString = outPutFileName.left(outPutFileName.length() - suffix.length() - 1) + QString("(%1)").arg(QString::number(index + 1)) + stres;
 
     // 多线程保存文件修复大文件卡顿问题
-    QtConcurrent::run(QThreadPool::globalInstance(), [srcImage, tmpString, isJpegImage] {
-        srcImage.save(tmpString, isJpegImage ? "JPEG" : "PNG");
+    (void)QtConcurrent::run(QThreadPool::globalInstance(), [srcImage, tmpString, isJpegImage] {
+        const QFileInfo file(tmpString);
+        const auto fileName = file.absolutePath() + "/" + truncateFileName(file.fileName());
+        if (!srcImage.save(fileName, isJpegImage ? "JPEG" : "PNG")) {
+            qWarning() << "Failed to save image to file, filePath:" << fileName;
+        }
     });
 }
 
@@ -99,7 +114,7 @@ void DPrintPreviewWidgetPrivate::populateScene()
     background->setBrush(Qt::white);
     background->setPen(Qt::NoPen);
 
-    for (auto *page : qAsConst(pages))
+    for (auto *page : std::as_const(pages))
         scene->removeItem(page);
     qDeleteAll(pages);
     pages.clear();
@@ -1137,13 +1152,13 @@ void DPrintPreviewWidgetPrivate::updateNumberUpContent()
 
     // 调整序号角标
     QVector<int> nVector;
-    for (auto &i : qAsConst(numberUpPrintData->previewPictures)) {
+    for (auto &i : std::as_const(numberUpPrintData->previewPictures)) {
         nVector.append(i.first);
     }
 
     // 调整序号坐标显示位置（纸张大小发生改变时）
     QVector<QPointF> paintPoints;
-    for (auto &p : qAsConst(numberUpPrintData->paintPoints)) {
+    for (auto &p : std::as_const(numberUpPrintData->paintPoints)) {
         paintPoints.append(p + QPointF(previewPrinter->pageLayout().paintRectPixels(previewPrinter->resolution()).width() * numberUpPrintData->scaleRatio, 0));
     }
 
@@ -1207,7 +1222,7 @@ QVector<int> DPrintPreviewWidgetPrivate::requestPages(int page)
   \a parent 父控件
  */
 DPrintPreviewWidget::DPrintPreviewWidget(DPrinter *printer, QWidget *parent)
-    : DFrame(*new DPrintPreviewWidgetPrivate(this))
+    : DFrame(*new DPrintPreviewWidgetPrivate(this), parent)
 {
     Q_D(DPrintPreviewWidget);
     d->previewPrinter = printer;
@@ -1399,9 +1414,7 @@ void DPrintPreviewWidget::setColorMode(const DPrinter::ColorMode &colorMode)
 void DPrintPreviewWidget::setOrientation(const DPrinter::Orientation &pageOrientation)
 {
     Q_D(DPrintPreviewWidget);
-    auto layout = d->previewPrinter->pageLayout();
-    layout.setOrientation(static_cast<QPageLayout::Orientation>(pageOrientation));
-    d->previewPrinter->setPageLayout(layout);
+    d->previewPrinter->setPageOrientation(static_cast<QPageLayout::Orientation>(pageOrientation));
     updatePreview();
 }
 
